==> crowdsec_1.4.2.orig-hub1.tar.gz: hub1/collections/crowdsecurity/http-cve.md <==
A collection of http specific CVEs :

 - [Apache CVE-2021-41773](https://cve.circl.lu/cve/CVE-2021-41773)
 - [Apache CVE-2021-42013](https://cve.circl.lu/cve/CVE-2021-42013)
 - [Grafana CVE-2021-43798](https://cve.circl.lu/cve/CVE-2021-43798)
 - [Fortinet CVE-2018-13379](https://cve.circl.lu/cve/CVE-2018-13379)
 - [Pulse Secure CVE-2019-11510](https://cve.circl.lu/cve/CVE-2019-11510)
 - [F5 BIG-IP CVE-2020-5902](https://cve.circl.lu/cve/CVE-2020-5902)
 - [ThinkPHP CVE-2018-20062](https://cve.circl.lu/cve/CVE-2018-20062)
 - [Apache Log4j2 CVE-2021-44228](https://cve.circl.lu/cve/CVE-2021-44228)
 - [VMware VMSA-2021-0027](https://www.vmware.com/security/advisories/VMSA-2021-0027.html)
 - [Atlassian Jira CVE-2021-26086](https://cve.circl.lu/cve/CVE-2021-26086)
 - [Spring4Shell CVE-2022-22965](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-22965)
 - [VMware CVE-2022-22954](https://www.vmware.com/security/advisories/VMSA-2022-0011.html)
 - [GLPI CVE-2022-35914](https://nvd.nist.gov/vuln/detail/CVE-2022-35914)
 - [Fortinet CVE-2022-40684](https://www.horizon3.ai/fortios-fortiproxy-and-fortiswitchmanager-authentication-bypass-technical-deep-dive-cve-2022-40684/)
 - [Confluence CVE-2022-26134](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-26134)
 - [Text4Shell CVE-2022-42889](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-42889)


:warning: This collection is _not_ a WAF and this collection does _not_ aims at replacing a WAF.

As such, an attacker might be able to bypass those signatures.

==> crowdsec_1.4.6.orig-hub1.tar.gz: hub1/collections/crowdsecurity/http-cve.md <==
A collection of http specific CVEs :

 - [Apache CVE-2021-41773](https://cve.circl.lu/cve/CVE-2021-41773)
 - [Apache CVE-2021-42013](https://cve.circl.lu/cve/CVE-2021-42013)
 - [Grafana CVE-2021-43798](https://cve.circl.lu/cve/CVE-2021-43798)
 - [Fortinet CVE-2018-13379](https://cve.circl.lu/cve/CVE-2018-13379)
 - [Pulse Secure CVE-2019-11510](https://cve.circl.lu/cve/CVE-2019-11510)
 - [F5 BIG-IP CVE-2020-5902](https://cve.circl.lu/cve/CVE-2020-5902)
 - [ThinkPHP CVE-2018-20062](https://cve.circl.lu/cve/CVE-2018-20062)
 - [Apache Log4j2 CVE-2021-44228](https://cve.circl.lu/cve/CVE-2021-44228)
 - [VMware VMSA-2021-0027](https://www.vmware.com/security/advisories/VMSA-2021-0027.html)
 - [Atlassian Jira CVE-2021-26086](https://cve.circl.lu/cve/CVE-2021-26086)
 - [Spring4Shell CVE-2022-22965](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-22965)
 - [VMware CVE-2022-22954](https://www.vmware.com/security/advisories/VMSA-2022-0011.html)
 - [GLPI CVE-2022-35914](https://nvd.nist.gov/vuln/detail/CVE-2022-35914)
 - [Fortinet CVE-2022-40684](https://www.horizon3.ai/fortios-fortiproxy-and-fortiswitchmanager-authentication-bypass-technical-deep-dive-cve-2022-40684/)
 - [Confluence CVE-2022-26134](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-26134)
 - [Text4Shell CVE-2022-42889](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-42889)
 - [Ghost CMS CVE-2022-41697](https://nvd.nist.gov/vuln/detail/CVE-2022-41697)
 - [Cacti CVE-2022-46169](https://nvd.nist.gov/vuln/detail/CVE-2022-46169)
 - [Centos Web Panel 7 CVE-2022-44877](https://nvd.nist.gov/vuln/detail/CVE-2022-44877)


:warning: This collection is _not_ a WAF and this collection does _not_ aims at replacing a WAF.

As such, an attacker might be able to bypass those signatures.
